==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/lib/gfx/mod-gl/gl-view/gl-flat/gl-flat-backend.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdio.h>
#include <stdlib.h>

#include <string.h>

#include "config.h"
#include "../../../gfx.h"
#include "gl-flat.h"
#include "gl-flat-internal.h"

MOD_GL_VIEW_BACKEND *
mod_gl_view_flat_create_backend (MOD_GL_UTILS_CONTEXT * utils_context)
{
  MOD_GL_VIEW_BACKEND *backend;

  backend =
    (MOD_GL_VIEW_BACKEND *) LW6SYS_MALLOC (sizeof (MOD_GL_VIEW_BACKEND));
  if (backend)
    {
      memset (backend, 0, sizeof (MOD_GL_VIEW_BACKEND));

      backend->display_preview = mod_gl_view_flat_display_preview;
      backend->display_zones = mod_gl_view_flat_display_zones;
      backend->display_gradient = mod_gl_view_flat_display_gradient;
      backend->display_game = mod_gl_view_flat_display_game;
      backend->pick_map_coord = mod_gl_view_flat_pick_map_coord;
      backend->init = mod_gl_view_flat_init;
      backend->quit = mod_gl_view_flat_quit;
    }

  return backend;
}

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/lib/gfx/mod-gl/gl-view/gl-flat/gl-flat-backend.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdio.h>
#include <stdlib.h>

#include <string.h>

#include "config.h"
#include "../../../gfx.h"
#include "gl-flat.h"
#include "gl-flat-internal.h"

MOD_GL_VIEW_BACKEND *
mod_gl_view_flat_create_backend (MOD_GL_UTILS_CONTEXT * utils_context)
{
  MOD_GL_VIEW_BACKEND *backend;

  backend =
    (MOD_GL_VIEW_BACKEND *) LW6SYS_MALLOC (sizeof (MOD_GL_VIEW_BACKEND));
  if (backend)
    {
      memset (backend, 0, sizeof (MOD_GL_VIEW_BACKEND));

      backend->display_preview = mod_gl_view_flat_display_preview;
      backend->display_zones = mod_gl_view_flat_display_zones;
      backend->display_gradient = mod_gl_view_flat_display_gradient;
      backend->display_game = mod_gl_view_flat_display_game;
      backend->pick_map_coord = mod_gl_view_flat_pick_map_coord;
      backend->init = mod_gl_view_flat_init;
      backend->quit = mod_gl_view_flat_quit;
    }

  return backend;
}
